"""Windows related test code."""

def setup_action_queue_test(testcase):
    """Extra setup to be performed for the action queue tests."""
    # nothing to be done
    pass


def setup_main_test(testcase):
    """Extra setup to be performed for the main tests."""
    # nothing to be done
    pass


def get_main_params(testcase, params):
    """Return the parameters used to create the main object for tests."""
    params['glib_loop'] = False
    return params
